==> tcm-kityminder-core-1.0.3.tgz: package/src/module/execution-status.js <==
define(function(require, exports, module) {
    var kity = require('../core/kity');
    var utils = require('../core/utils');

    var Minder = require('../core/minder');
    var MinderNode = require('../core/node');
    var Command = require('../core/command');
    var Module = require('../core/module');
    var Renderer = require('../core/render');

    Module.register('ExecutionStatusModule', function() {
        var minder = this;

        var STATUS_COLORS = {
            'NOTRUN': ['white', 'rgb(192, 196, 204)'],
            'PASS': ['white', 'rgb(103, 194, 58)'],
            'FAIL': ['white', 'rgb(245, 108, 108)'],
            'SKIP': ['white', 'rgb(230, 162, 60)']
        };
        // jscs:disable maximumLineLength
        var MASK_PATH = {
            'SKIP': 'M8.46457 14.1213C8.07404 14.5118 8.07404 15.145 8.46457 15.5355C8.85509 15.926 9.48825 15.926 9.87878 15.5355L15.5356 9.87862C15.9262 9.4881 15.9262 8.85493 15.5356 8.46441C15.1451 8.07388 14.5119 8.07388 14.1214 8.46441L8.46457 14.1213Z',
            'NOTRUN': 'M8 11C7.44772 11 7 11.4477 7 12C7 12.5523 7.44772 13 8 13H16C16.5523 13 17 12.5523 17 12C17 11.4477 16.5523 11 16 11H8Z',
            'PASS': 'M10.2426 16.3137L6 12.071L7.41421 10.6568L10.2426 13.4853L15.8995 7.8284L17.3137 9.24262L10.2426 16.3137Z',
            'FAIL': 'M16.3394 9.32245C16.7434 8.94589 16.7657 8.31312 16.3891 7.90911C16.0126 7.50509 15.3798 7.48283 14.9758 7.85938L12.0497 10.5866L9.32245 7.66048C8.94589 7.25647 8.31312 7.23421 7.90911 7.61076C7.50509 7.98731 7.48283 8.62008 7.85938 9.0241L10.5866 11.9502L7.66048 14.6775C7.25647 15.054 7.23421 15.6868 7.61076 16.0908C7.98731 16.4948 8.62008 16.5171 9.0241 16.1405L11.9502 13.4133L14.6775 16.3394C15.054 16.7434 15.6868 16.7657 16.0908 16.3891C16.4948 16.0126 16.5171 15.3798 16.1405 14.9758L13.4133 12.0497L16.3394 9.32245Z',
        };
        var BACK_PATH = {
            'SKIP': 'M1 12C1 5.92487 5.92487 1 12 1C18.0751 1 23 5.92487 23 12C23 18.0751 18.0751 23 12 23C5.92487 23 1 18.0751 1 12ZM12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21Z',
            'NOTRUN': 'M23 12C23 18.0751 18.0751 23 12 23C5.92487 23 1 18.0751 1 12C1 5.92487 5.92487 1 12 1C18.0751 1 23 5.92487 23 12ZM21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z',
            'PASS': 'M1 12C1 5.92487 5.92487 1 12 1C18.0751 1 23 5.92487 23 12C23 18.0751 18.0751 23 12 23C5.92487 23 1 18.0751 1 12ZM12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21Z',
            'FAIL': 'M1 12C1 5.92487 5.92487 1 12 1C18.0751 1 23 5.92487 23 12C23 18.0751 18.0751 23 12 23C5.92487 23 1 18.0751 1 12ZM12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21Z',
        };

        var EXECUTION_DATA = 'executionStatus';

        // 执行状态图标
        var ExecutionStatusIcon = kity.createClass('ExecutionStatusIcon', {
            base: kity.Group,

            constructor: function(value) {
                this.callBase();
                this.setSize(24);
                this.create(value);
                this.setValue(value);
                this.setId(utils.uuid('node_execution_status'));
            },

            setSize: function(size) {
                this.width = this.height = size;
            },

            create: function(value) {
                var back, mask; // 4 layer
                back = new kity.Path().setPathData(BACK_PATH[value]).setTranslate(0.5, 0.5);
                mask = new kity.Path().setPathData(MASK_PATH[value]).setOpacity(1).setTranslate(0.5, 0.5);

                this.addShapes([back, mask]);
                this.mask = mask;
                this.back = back;
            },

            setValue: function(value) {
                var back = this.back,
                    mask = this.mask;
                back.setPathData(BACK_PATH[value]);
                mask.setPathData(MASK_PATH[value]);
                var color = STATUS_COLORS[value] || ['white', 'rgb(103, 194, 58)'];

                if (color) {
                    back.fill(color[1]);
                    mask.fill(color[0]);
                }
            }
        });

        /**
         *设置执行状态
         */
        var ExecutionCommand = kity.createClass('SetExecutionStatusCommand', {
            base: Command,
            execute: function(km, value) {
                var nodes = km.getSelectedNodes();
                for (var i = 0; i < nodes.length; i++) {
                    nodes[i].setData(EXECUTION_DATA, value || null).render();
                }
                km.layout();
            },
            queryValue: function(km) {
                var nodes = km.getSelectedNodes();
                var val;
                for (var i = 0; i < nodes.length; i++) {
                    val = nodes[i].getData(EXECUTION_DATA);
                    if (val) break;
                }
                return val || null;
            },

            queryState: function(km) {
                return km.getSelectedNodes().length ? 0 : -1;
            }
        });


        /**
         * @command 标记状态快捷键
         * @description 向上调整选中节点的位置
         * @shortcut Option +
         */
        var ExecutionPCommand = kity.createClass('ExecutionPCommand', {
            base: Command,

            execute: function(km) {
                var nodes = km.getSelectedNodes();
                for (var i = 0; i < nodes.length; i++) {
                    nodes[i].setData(EXECUTION_DATA, 'PASS').render();
                }
                km.layout();
            },
            queryState: function(km) {
                return km.getSelectedNodes().length ? 0 : -1;
            }
        });

        /**
         * @command 标记状态快捷键
         * @description 向上调整选中节点的位置
         * @shortcut Option +
         */
        var ExecutionFCommand = kity.createClass('ExecutionPCommand', {
            base: Command,

            execute: function(km) {
                var nodes = km.getSelectedNodes();
                for (var i = 0; i < nodes.length; i++) {
                    nodes[i].setData(EXECUTION_DATA, 'FAIL').render();
                }
                km.layout();
            },
            queryState: function(km) {
                return km.getSelectedNodes().length ? 0 : -1;
            }
        });

        /**
         * @command 标记状态快捷键
         * @description 向上调整选中节点的位置
         * @shortcut Option +
         */
        var ExecutionSCommand = kity.createClass('ExecutionPCommand', {
            base: Command,

            execute: function(km) {
                var nodes = km.getSelectedNodes();
                for (var i = 0; i < nodes.length; i++) {
                    nodes[i].setData(EXECUTION_DATA, 'SKIP').render();
                }
                km.layout();
            },
            queryState: function(km) {
                return km.getSelectedNodes().length ? 0 : -1;
            }
        });

        /**
         * @command 标记状态快捷键
         * @description 向上调整选中节点的位置
         * @shortcut Option +
         */
        var ExecutionNCommand = kity.createClass('ExecutionPCommand', {
            base: Command,

            execute: function(km) {
                var nodes = km.getSelectedNodes();
                for (var i = 0; i < nodes.length; i++) {
                    nodes[i].setData(EXECUTION_DATA, 'NOTRUN').render();
                }
                km.layout();
            },
            queryState: function(km) {
                return km.getSelectedNodes().length ? 0 : -1;
            }
        });

        return {
            'commands': {
                'execution': ExecutionCommand,
                'ExecutionP': ExecutionPCommand,
                'ExecutionF': ExecutionFCommand,
                'ExecutionS': ExecutionSCommand,
                'ExecutionN': ExecutionNCommand,
            },
            'renderers': {
                left: kity.createClass('ExecutionRenderer', {
                    base: Renderer,

                    create: function(node) {
                        return new ExecutionStatusIcon();
                    },

                    shouldRender: function(node) {
                        return node.getData(EXECUTION_DATA);
                    },

                    update: function(icon, node, box) {
                        var data = node.getData(EXECUTION_DATA);
                        var spaceLeft = node.getStyle('space-left'),
                            x, y;

                        icon.setValue(data);
                        x = box.left - icon.width - spaceLeft;
                        y = -icon.height / 2;

                        icon.setTranslate(x, y);

                        return new kity.Box({
                            x: x,
                            y: y,
                            width: icon.width,
                            height: icon.height
                        });
                    }
                })
            },
            commandShortcutKeys: {
                ExecutionP: "normal::alt+p",
                ExecutionF: "normal::alt+f",
                ExecutionN: "normal::alt+k",
                ExecutionS: "normal::alt+o",
                execution: "normal::alt+l",
            }
        };
    });
});

==> tcm-kityminder-core-1.0.11.tgz: package/src/module/execution-status.js <==
define(function(require, exports, module) {
    var kity = require('../core/kity');
    var utils = require('../core/utils');

    var Minder = require('../core/minder');
    var MinderNode = require('../core/node');
    var Command = require('../core/command');
    var Module = require('../core/module');
    var Renderer = require('../core/render');

    Module.register('ExecutionStatusModule', function() {
        var minder = this;

        var STATUS_COLORS = {
            'NOTRUN': ['white', 'rgb(192, 196, 204)'],
            'PASS': ['white', 'rgb(103, 194, 58)'],
            'FAIL': ['white', 'rgb(245, 108, 108)'],
            'SKIP': ['white', 'rgb(230, 162, 60)']
        };
        // jscs:disable maximumLineLength
        var MASK_PATH = {
            'SKIP': 'M8.46457 14.1213C8.07404 14.5118 8.07404 15.145 8.46457 15.5355C8.85509 15.926 9.48825 15.926 9.87878 15.5355L15.5356 9.87862C15.9262 9.4881 15.9262 8.85493 15.5356 8.46441C15.1451 8.07388 14.5119 8.07388 14.1214 8.46441L8.46457 14.1213Z',
            'NOTRUN': 'M8 11C7.44772 11 7 11.4477 7 12C7 12.5523 7.44772 13 8 13H16C16.5523 13 17 12.5523 17 12C17 11.4477 16.5523 11 16 11H8Z',
            'PASS': 'M10.2426 16.3137L6 12.071L7.41421 10.6568L10.2426 13.4853L15.8995 7.8284L17.3137 9.24262L10.2426 16.3137Z',
            'FAIL': 'M16.3394 9.32245C16.7434 8.94589 16.7657 8.31312 16.3891 7.90911C16.0126 7.50509 15.3798 7.48283 14.9758 7.85938L12.0497 10.5866L9.32245 7.66048C8.94589 7.25647 8.31312 7.23421 7.90911 7.61076C7.50509 7.98731 7.48283 8.62008 7.85938 9.0241L10.5866 11.9502L7.66048 14.6775C7.25647 15.054 7.23421 15.6868 7.61076 16.0908C7.98731 16.4948 8.62008 16.5171 9.0241 16.1405L11.9502 13.4133L14.6775 16.3394C15.054 16.7434 15.6868 16.7657 16.0908 16.3891C16.4948 16.0126 16.5171 15.3798 16.1405 14.9758L13.4133 12.0497L16.3394 9.32245Z',
        };
        var BACK_PATH = {
            'SKIP': 'M1 12C1 5.92487 5.92487 1 12 1C18.0751 1 23 5.92487 23 12C23 18.0751 18.0751 23 12 23C5.92487 23 1 18.0751 1 12ZM12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21Z',
            'NOTRUN': 'M23 12C23 18.0751 18.0751 23 12 23C5.92487 23 1 18.0751 1 12C1 5.92487 5.92487 1 12 1C18.0751 1 23 5.92487 23 12ZM21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z',
            'PASS': 'M1 12C1 5.92487 5.92487 1 12 1C18.0751 1 23 5.92487 23 12C23 18.0751 18.0751 23 12 23C5.92487 23 1 18.0751 1 12ZM12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21Z',
            'FAIL': 'M1 12C1 5.92487 5.92487 1 12 1C18.0751 1 23 5.92487 23 12C23 18.0751 18.0751 23 12 23C5.92487 23 1 18.0751 1 12ZM12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21Z',
        };

        var EXECUTION_DATA = 'executionStatus';

        // 执行状态图标
        var ExecutionStatusIcon = kity.createClass('ExecutionStatusIcon', {
            base: kity.Group,

            constructor: function(value) {
                this.callBase();
                this.setSize(24);
                this.create(value);
                this.setValue(value);
                this.setId(utils.uuid('node_execution_status'));
            },

            setSize: function(size) {
                this.width = this.height = size;
            },

            create: function(value) {
                var back, mask; // 4 layer
                back = new kity.Path().setPathData(BACK_PATH[value]).setTranslate(0.5, 0.5);
                mask = new kity.Path().setPathData(MASK_PATH[value]).setOpacity(1).setTranslate(0.5, 0.5);

                this.addShapes([back, mask]);
                this.mask = mask;
                this.back = back;
            },

            setValue: function(value) {
                var back = this.back,
                    mask = this.mask;
                back.setPathData(BACK_PATH[value]);
                mask.setPathData(MASK_PATH[value]);
                var color = STATUS_COLORS[value] || ['white', 'rgb(103, 194, 58)'];

                if (color) {
                    back.fill(color[1]);
                    mask.fill(color[0]);
                }
            }
        });

        /**
         *设置执行状态
         */
        var ExecutionCommand = kity.createClass('SetExecutionStatusCommand', {
            base: Command,
            execute: function(km, value) {
                var nodes = km.getSelectedNodes();
                for (var i = 0; i < nodes.length; i++) {
                    nodes[i].setData(EXECUTION_DATA, value || null).render();
                }
                km.layout();
            },
            queryValue: function(km) {
                var nodes = km.getSelectedNodes();
                var val;
                for (var i = 0; i < nodes.length; i++) {
                    val = nodes[i].getData(EXECUTION_DATA);
                    if (val) break;
                }
                return val || null;
            },

            queryState: function(km) {
                return km.getSelectedNodes().length ? 0 : -1;
            }
        });


        /**
         * @command 标记状态快捷键
         * @description 向上调整选中节点的位置
         * @shortcut Option +
         */
        var ExecutionPCommand = kity.createClass('ExecutionPCommand', {
            base: Command,

            execute: function(km) {
                var nodes = km.getSelectedNodes();
                for (var i = 0; i < nodes.length; i++) {
                    nodes[i].setData(EXECUTION_DATA, 'PASS').render();
                }
                km.layout();
            },
            queryState: function(km) {
                return km.getSelectedNodes().length ? 0 : -1;
            }
        });

        /**
         * @command 标记状态快捷键
         * @description 向上调整选中节点的位置
         * @shortcut Option +
         */
        var ExecutionFCommand = kity.createClass('ExecutionPCommand', {
            base: Command,

            execute: function(km) {
                var nodes = km.getSelectedNodes();
                for (var i = 0; i < nodes.length; i++) {
                    nodes[i].setData(EXECUTION_DATA, 'FAIL').render();
                }
                km.layout();
            },
            queryState: function(km) {
                return km.getSelectedNodes().length ? 0 : -1;
            }
        });

        /**
         * @command 标记状态快捷键
         * @description 向上调整选中节点的位置
         * @shortcut Option +
         */
        var ExecutionSCommand = kity.createClass('ExecutionPCommand', {
            base: Command,

            execute: function(km) {
                var nodes = km.getSelectedNodes();
                for (var i = 0; i < nodes.length; i++) {
                    nodes[i].setData(EXECUTION_DATA, 'SKIP').render();
                }
                km.layout();
            },
            queryState: function(km) {
                return km.getSelectedNodes().length ? 0 : -1;
            }
        });

        /**
         * @command 标记状态快捷键
         * @description 向上调整选中节点的位置
         * @shortcut Option +
         */
        var ExecutionNCommand = kity.createClass('ExecutionPCommand', {
            base: Command,

            execute: function(km) {
                var nodes = km.getSelectedNodes();
                for (var i = 0; i < nodes.length; i++) {
                    nodes[i].setData(EXECUTION_DATA, 'NOTRUN').render();
                }
                km.layout();
            },
            queryState: function(km) {
                return km.getSelectedNodes().length ? 0 : -1;
            }
        });

        return {
            'commands': {
                'execution': ExecutionCommand,
                'ExecutionP': ExecutionPCommand,
                'ExecutionF': ExecutionFCommand,
                'ExecutionS': ExecutionSCommand,
                'ExecutionN': ExecutionNCommand,
            },
            'renderers': {
                left: kity.createClass('ExecutionRenderer', {
                    base: Renderer,

                    create: function(node) {
                        return new ExecutionStatusIcon();
                    },

                    shouldRender: function(node) {
                        return node.getData(EXECUTION_DATA);
                    },

                    update: function(icon, node, box) {
                        var data = node.getData(EXECUTION_DATA);
                        var spaceLeft = node.getStyle('space-left'),
                            x, y;

                        icon.setValue(data);
                        x = box.left - icon.width - spaceLeft;
                        y = -icon.height / 2;

                        icon.setTranslate(x, y);

                        return new kity.Box({
                            x: x,
                            y: y,
                            width: icon.width,
                            height: icon.height
                        });
                    }
                })
            },
            commandShortcutKeys: {
                ExecutionP: "normal::ctrl+1",
                ExecutionF: "normal::ctrl+2",
                ExecutionS: "normal::ctrl+3",
                ExecutionN: "normal::ctrl+4",
                execution: "normal::ctrl+5",
            }
        };
    });
});
